@@ -39,8 +39,8 @@
 #'     data if different from the training set.}
 #' }
 #'
-#' Default values and further model details can be found in the source links
-#' below.
+#' Default argument values and further model details can be found in the source
+#' See Also links below.
 #'
 #' @return \code{MLModel} class object.
 #'
@@ -85,7 +85,8 @@ FDAModel <- function(
 
     fit = function(formula, data, weights, ...) {
       mda::fda(
-        formula, data = as.data.frame(formula, data), weights = weights, ...
+        formula, data = as.data.frame(formula, data = data), weights = weights,
+        ...
       )
     },
 
