@@ -53,8 +53,9 @@ diff.Performance <- function(x, ...) {
   indices2 <- indices[2, ]
   xdiff <- x[, , indices1, drop = FALSE] - x[, , indices2, drop = FALSE]
   model_names <- dimnames(x)[[3]]
-  dimnames(xdiff)[[3]] <-
-    paste(model_names[indices1], "-", model_names[indices2])
+  dimnames(xdiff)[[3]] <- paste(
+    model_names[indices1], "-", model_names[indices2]
+  )
   PerformanceDiff(xdiff, model_names = model_names, control = x@control)
 }
 
@@ -149,10 +150,12 @@ t.test.PerformanceDiff <- function(x, adjust = "holm", ...)
 
   model_names <- x@model_names
   num_models <- length(model_names)
-  results <- array(NA, dim = c(num_models, num_models, size(x, 2)),
-                   dimnames = list(Model2 = model_names,
-                                   Model1 = model_names,
-                                   Metric = dimnames(x)[[2]]))
+  results <- array(
+    NA, dim = c(num_models, num_models, size(x, 2)),
+    dimnames = list(
+      Model2 = model_names, Model1 = model_names, Metric = dimnames(x)[[2]]
+    )
+  )
   indices <- lower.tri(results[, , 1])
   results[indices] <- meandiffs
   results <- aperm(results, perm = c(2, 1, 3))
