@@ -53,6 +53,9 @@
 #' \code{\link[recipes]{bake}}
 #'
 #' @examples
+#' \donttest{
+#' ## Requires prior installation of suggested package cluster to run
+#'
 #' library(recipes)
 #'
 #' rec <- recipe(rating ~ ., data = attitude)
@@ -65,6 +68,7 @@
 #'
 #' tidy(kmedoids_rec, number = 1)
 #' tidy(kmedoids_prep, number = 1)
+#' }
 #'
 step_kmedoids <- function(
   recipe, ..., k = 5, center = TRUE, scale = TRUE, method = c("pam", "clara"),
@@ -115,14 +119,17 @@ new_step_kmedoids <- function(
     k <- min(max(step$k, 1), nrow(x) - 1)
     switch(step$method,
       "pam" = {
-        res <- cluster::pam(x, k, metric = step$metric, pamonce = step$optimize,
-                            keep.diss = FALSE, keep.data = FALSE)
+        res <- cluster::pam(
+          x, k, metric = step$metric, pamonce = step$optimize,
+          keep.diss = FALSE, keep.data = FALSE
+        )
       },
       "clara" = {
         samp_size <- min(step$samp_size, nrow(x))
-        res <- cluster::clara(x, k, metric = step$metric,
-                              samples = step$num_samp, sampsize = samp_size,
-                              medoids.x = FALSE, rngR = TRUE)
+        res <- cluster::clara(
+          x, k, metric = step$metric, samples = step$num_samp,
+          sampsize = samp_size, medoids.x = FALSE, rngR = TRUE
+        )
         names(res)[names(res) == "i.med"] <- "id.med"
       }
     )
@@ -150,8 +157,9 @@ new_step_kmedoids <- function(
       options$optimize <- optimize
     },
     "clara" = {
-      options$metric <- match.arg(metric,
-                                  c("euclidean", "manhattan", "jaccard"))
+      options$metric <- match.arg(
+        metric, c("euclidean", "manhattan", "jaccard")
+      )
       options$num_samp <- num_samp
       options$samp_size <- samp_size
     },
@@ -161,8 +169,9 @@ new_step_kmedoids <- function(
     }
   )
 
-  object <- new_step_sbf(..., filter = filter, multivariate = TRUE,
-                         options = options)
+  object <- new_step_sbf(
+    ..., filter = filter, multivariate = TRUE, options = options
+  )
   object$res <- tibble(
     terms = recipes::sel2char(object$terms),
     cluster = NA_integer_,
